@@ -26,6 +26,10 @@ from great_expectations.core.batch import (
     get_batch_request_as_dict,
 )
 from great_expectations.core.config_peer import ConfigOutputModes, ConfigPeer
+from great_expectations.core.expectation_validation_result import (
+    ExpectationSuiteValidationResult,
+    ExpectationSuiteValidationResultMeta,
+)
 from great_expectations.core.usage_statistics.events import UsageStatsEvents
 from great_expectations.core.usage_statistics.usage_statistics import (
     get_checkpoint_run_usage_statistics,
@@ -34,7 +38,6 @@ from great_expectations.core.usage_statistics.usage_statistics import (
 from great_expectations.core.util import get_datetime_string_from_strftime_format
 from great_expectations.data_asset import DataAsset
 from great_expectations.data_context.types.base import CheckpointConfig
-from great_expectations.data_context.types.resource_identifiers import GeCloudIdentifier
 from great_expectations.data_context.util import (
     instantiate_class_from_config,
     substitute_all_config_variables,
@@ -102,6 +105,10 @@ class BaseCheckpoint(ConfigPeer):
             run_id and run_time
         ), "Please provide either a run_id or run_name and/or run_time."
 
+        # If no validations are provided, the combination of expectation_suite_name, batch_request,
+        # and action_list are considered the "default" validation.
+        using_default_validation = not self.validations and not validations
+
         run_time = run_time or datetime.datetime.now()
         runtime_configuration = runtime_configuration or {}
         result_format = result_format or runtime_configuration.get("result_format")
@@ -131,7 +138,7 @@ class BaseCheckpoint(ConfigPeer):
         run_name_template = substituted_runtime_config.get("run_name_template")
 
         batch_request = substituted_runtime_config.get("batch_request")
-        validations = substituted_runtime_config.get("validations") or []
+        validations = cast(list, substituted_runtime_config.get("validations") or [])
 
         if len(validations) == 0 and not batch_request:
             raise ge_exceptions.CheckpointError(
@@ -145,6 +152,12 @@ class BaseCheckpoint(ConfigPeer):
 
         run_id = run_id or RunIdentifier(run_name=run_name, run_time=run_time)
 
+        # Ensure that validations dicts have the most specific id available
+        # (default to Checkpoint's default_validation_id if no validations were passed in the signature)
+        if using_default_validation:
+            for validation in validations:
+                validation["id_"] = self.config.default_validation_id
+
         # Use AsyncExecutor to speed up I/O bound validations by running them in parallel with multithreading (if
         # concurrency is enabled in the data context configuration) -- please see the below arguments used to initialize
         # AsyncExecutor and the corresponding AsyncExecutor docstring for more details on when multiple threads are
@@ -176,15 +189,27 @@ class BaseCheckpoint(ConfigPeer):
                     run_id=run_id,
                 )
 
-            run_results: dict = {}
+            checkpoint_run_results: dict = {}
+            async_validation_operator_result: AsyncResult
             for async_validation_operator_result in async_validation_operator_results:
-                run_results.update(
-                    async_validation_operator_result.result().run_results
-                )
+                async_result = async_validation_operator_result.result()
+                run_results = async_result.run_results
+
+                run_result: dict
+                validation_result: Optional[ExpectationSuiteValidationResult]
+                meta: ExpectationSuiteValidationResultMeta
+                for run_result in run_results.values():
+                    validation_result = run_result.get("validation_result")
+                    if validation_result:
+                        meta = validation_result.meta
+                        id_ = str(self.ge_cloud_id) if self.ge_cloud_id else None
+                        meta["checkpoint_id"] = id_
+
+                checkpoint_run_results.update(run_results)
 
         return CheckpointResult(
             run_id=run_id,
-            run_results=run_results,
+            run_results=checkpoint_run_results,
             checkpoint_config=self.config,
         )
 
@@ -291,6 +316,9 @@ class BaseCheckpoint(ConfigPeer):
     ) -> None:
         if validation_dict is None:
             validation_dict = {}
+            validation_dict["id_"] = substituted_runtime_config.get(
+                "default_validation_id"
+            )
 
         try:
             substituted_validation_dict: dict = get_substituted_validation_dict(
@@ -306,6 +334,9 @@ class BaseCheckpoint(ConfigPeer):
             expectation_suite_ge_cloud_id: str = substituted_validation_dict.get(
                 "expectation_suite_ge_cloud_id"
             )
+            include_rendered_content: bool = substituted_validation_dict.get(
+                "include_rendered_content", False
+            )
 
             validator: Validator = self.data_context.get_validator(
                 batch_request=batch_request,
@@ -319,6 +350,7 @@ class BaseCheckpoint(ConfigPeer):
                     if self.data_context.ge_cloud_mode
                     else None
                 ),
+                include_rendered_content=include_rendered_content,
             )
 
             action_list: list = substituted_validation_dict.get("action_list")
@@ -346,28 +378,29 @@ class BaseCheckpoint(ConfigPeer):
             )
             checkpoint_identifier = None
             if self.data_context.ge_cloud_mode:
-                checkpoint_identifier = GeCloudIdentifier(
-                    resource_type="contract", ge_cloud_id=str(self.ge_cloud_id)
-                )
+                checkpoint_identifier = self.ge_cloud_id
 
             operator_run_kwargs = {}
 
             if catch_exceptions_validation is not None:
                 operator_run_kwargs["catch_exceptions"] = catch_exceptions_validation
 
-            async_validation_operator_results.append(
-                async_executor.submit(
-                    action_list_validation_operator.run,
-                    assets_to_validate=[validator],
-                    run_id=run_id,
-                    evaluation_parameters=substituted_validation_dict.get(
-                        "evaluation_parameters"
-                    ),
-                    result_format=result_format,
-                    checkpoint_identifier=checkpoint_identifier,
-                    **operator_run_kwargs,
-                )
+            validation_id: Optional[str] = substituted_validation_dict.get("id_")
+
+            async_validation_operator_result = async_executor.submit(
+                action_list_validation_operator.run,
+                assets_to_validate=[validator],
+                run_id=run_id,
+                evaluation_parameters=substituted_validation_dict.get(
+                    "evaluation_parameters"
+                ),
+                result_format=result_format,
+                checkpoint_identifier=checkpoint_identifier,
+                checkpoint_name=self.name,
+                validation_id=validation_id,
+                **operator_run_kwargs,
             )
+            async_validation_operator_results.append(async_validation_operator_result)
         except (
             ge_exceptions.CheckpointError,
             ge_exceptions.ExecutionEngineError,
@@ -511,6 +544,7 @@ class Checkpoint(BaseCheckpoint):
         batches: Optional[List[dict]] = None,
         ge_cloud_id: Optional[UUID] = None,
         expectation_suite_ge_cloud_id: Optional[UUID] = None,
+        default_validation_id: Optional[str] = None,
     ) -> None:
         # Only primitive types are allowed as constructor arguments; data frames are supplied to "run()" as arguments.
         if batch_request_contains_batch_data(batch_request=batch_request):
@@ -527,7 +561,7 @@ constructor arguments.
 """
             )
 
-        checkpoint_config: CheckpointConfig = CheckpointConfig(
+        checkpoint_config = CheckpointConfig(
             name=name,
             config_version=config_version,
             template_name=template_name,
@@ -543,6 +577,7 @@ constructor arguments.
             batches=batches,
             ge_cloud_id=ge_cloud_id,
             expectation_suite_ge_cloud_id=expectation_suite_ge_cloud_id,
+            default_validation_id=default_validation_id,
         )
         super().__init__(
             checkpoint_config=checkpoint_config,
@@ -651,6 +686,7 @@ constructor arguments.
         notify_with: Optional[Union[str, List[str]]] = None,
         ge_cloud_id: Optional[str] = None,
         expectation_suite_ge_cloud_id: Optional[str] = None,
+        default_validation_id: Optional[str] = None,
     ) -> "Checkpoint":
         checkpoint_config: Union[CheckpointConfig, dict]
 
@@ -695,6 +731,7 @@ constructor arguments.
             "notify_with": notify_with,
             "ge_cloud_id": ge_cloud_id,
             "expectation_suite_ge_cloud_id": expectation_suite_ge_cloud_id,
+            "default_validation_id": default_validation_id,
         }
 
         checkpoint_config = deep_filter_properties_iterable(
