@@ -304,7 +304,7 @@ def find_evaluation_parameter_dependencies(parameter_expression):
     return dependencies
 
 
-def parse_evaluation_parameter(
+def parse_evaluation_parameter(  # noqa: C901 - complexity 21
     parameter_expression: str,
     evaluation_parameters: Optional[Dict[str, Any]] = None,
     data_context: Optional[Any] = None,  # Cannot type 'DataContext' due to import cycle
