@@ -20,6 +20,7 @@ from great_expectations.core.util import (
     nested_update,
 )
 from great_expectations.exceptions import (
+    ExpectationNotFoundError,
     InvalidExpectationConfigurationError,
     InvalidExpectationKwargsError,
     ParserError,
@@ -1124,16 +1125,17 @@ class ExpectationConfiguration(SerializableDictDot):
             self.expectation_type, None
         )
         if expectation_kwargs_dict is None:
-            impl = get_expectation_impl(self.expectation_type)
-            if impl is not None:
-                domain_keys = impl.domain_keys
-                default_kwarg_values = impl.default_kwarg_values
-            else:
+            try:
+                impl = get_expectation_impl(self.expectation_type)
+            except ExpectationNotFoundError:
                 expectation_kwargs_dict = self._get_default_custom_kwargs()
                 default_kwarg_values = expectation_kwargs_dict.get(
                     "default_kwarg_values", {}
                 )
                 domain_keys = expectation_kwargs_dict["domain_kwargs"]
+            else:
+                domain_keys = impl.domain_keys
+                default_kwarg_values = impl.default_kwarg_values
         else:
             default_kwarg_values = expectation_kwargs_dict.get(
                 "default_kwarg_values", {}
@@ -1157,16 +1159,17 @@ class ExpectationConfiguration(SerializableDictDot):
             self.expectation_type, None
         )
         if expectation_kwargs_dict is None:
-            impl = get_expectation_impl(self.expectation_type)
-            if impl is not None:
-                success_keys = impl.success_keys
-                default_kwarg_values = impl.default_kwarg_values
-            else:
+            try:
+                impl = get_expectation_impl(self.expectation_type)
+            except ExpectationNotFoundError:
                 expectation_kwargs_dict = self._get_default_custom_kwargs()
                 default_kwarg_values = expectation_kwargs_dict.get(
                     "default_kwarg_values", {}
                 )
                 success_keys = expectation_kwargs_dict["success_kwargs"]
+            else:
+                success_keys = impl.success_keys
+                default_kwarg_values = impl.default_kwarg_values
         else:
             default_kwarg_values = expectation_kwargs_dict.get(
                 "default_kwarg_values", {}
@@ -1187,16 +1190,17 @@ class ExpectationConfiguration(SerializableDictDot):
             self.expectation_type, None
         )
         if expectation_kwargs_dict is None:
-            impl = get_expectation_impl(self.expectation_type)
-            if impl is not None:
-                runtime_keys = impl.runtime_keys
-                default_kwarg_values = impl.default_kwarg_values
-            else:
+            try:
+                impl = get_expectation_impl(self.expectation_type)
+            except ExpectationNotFoundError:
                 expectation_kwargs_dict = self._get_default_custom_kwargs()
                 default_kwarg_values = expectation_kwargs_dict.get(
                     "default_kwarg_values", {}
                 )
                 runtime_keys = self.runtime_kwargs
+            else:
+                runtime_keys = impl.runtime_keys
+                default_kwarg_values = impl.default_kwarg_values
         else:
             default_kwarg_values = expectation_kwargs_dict.get(
                 "default_kwarg_values", {}
