@@ -218,7 +218,7 @@ class ExpectationValidationResult(SerializableDictDot):
             "class_name": "InlineRenderer",
             "render_object": self,
         }
-        module_name: str = "great_expectations.render.renderer.inline_renderer"
+        module_name = "great_expectations.render.renderer.inline_renderer"
         inline_renderer = instantiate_class_from_config(
             config=inline_renderer_config,
             runtime_environment={},
@@ -234,7 +234,7 @@ class ExpectationValidationResult(SerializableDictDot):
         (
             self.expectation_config.rendered_content,
             self.rendered_content,
-        ) = inline_renderer.render()
+        ) = inline_renderer.get_expectation_validation_result_rendered_content()
 
     @staticmethod
     def validate_result_dict(result):
