@@ -3,21 +3,31 @@ import logging
 import os
 import random
 import uuid
-from typing import Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Union
 
 import great_expectations.exceptions as ge_exceptions
+from great_expectations.core.data_context_key import DataContextKey
 from great_expectations.data_context.store import ConfigurationStore
+from great_expectations.data_context.store.ge_cloud_store_backend import (
+    GeCloudRESTResource,
+)
 from great_expectations.data_context.types.base import (
     CheckpointConfig,
     DataContextConfigDefaults,
 )
-from great_expectations.data_context.types.refs import GeCloudIdAwareRef
+from great_expectations.data_context.types.refs import (
+    GeCloudIdAwareRef,
+    GeCloudResourceRef,
+)
 from great_expectations.data_context.types.resource_identifiers import (
     ConfigurationIdentifier,
     GeCloudIdentifier,
 )
 from great_expectations.marshmallow__shade import ValidationError
 
+if TYPE_CHECKING:
+    from great_expectations.checkpoint import Checkpoint
+
 logger = logging.getLogger(__name__)
 
 
@@ -39,18 +49,22 @@ class CheckpointStore(ConfigurationStore):
         ]
         checkpoint_config_dict["ge_cloud_id"] = ge_cloud_checkpoint_id
 
+        # Checkpoints accept a `ge_cloud_id` but not an `id`
+        checkpoint_config_dict.pop("id", None)
+
         return checkpoint_config_dict
 
     def serialization_self_check(self, pretty_print: bool) -> None:
         test_checkpoint_name: str = "test-name-" + "".join(
             [random.choice(list("0123456789ABCDEF")) for i in range(20)]
         )
-        test_checkpoint_configuration: CheckpointConfig = CheckpointConfig(
+        test_checkpoint_configuration = CheckpointConfig(
             **{"name": test_checkpoint_name}
         )
         if self.ge_cloud_mode:
             test_key: GeCloudIdentifier = self.key_class(
-                resource_type="contract", ge_cloud_id=str(uuid.uuid4())
+                resource_type=GeCloudRESTResource.CHECKPOINT,
+                ge_cloud_id=str(uuid.uuid4()),
             )
         else:
             test_key: ConfigurationIdentifier = self.key_class(
@@ -67,8 +81,8 @@ class CheckpointStore(ConfigurationStore):
             print(
                 f"Attempting to retrieve the test value associated with key {test_key} from Checkpoint store..."
             )
-        # noinspection PyUnusedLocal
-        test_value: CheckpointConfig = self.get(key=test_key)
+
+        self.get(key=test_key)
         if pretty_print:
             print("\tTest value successfully retrieved from Checkpoint store.")
             print()
@@ -76,8 +90,7 @@ class CheckpointStore(ConfigurationStore):
         if pretty_print:
             print(f"Cleaning up test key {test_key} and value from Checkpoint store...")
 
-        # noinspection PyUnusedLocal
-        test_value: CheckpointConfig = self.remove_key(key=test_key)
+        self.remove_key(key=test_key)
         if pretty_print:
             print("\tTest key and value successfully removed from Checkpoint store.")
             print()
@@ -138,7 +151,7 @@ class CheckpointStore(ConfigurationStore):
                 batches is not None
                 and (
                     len(batches) == 0
-                    or {"batch_kwargs", "expectation_suite_names",}.issubset(
+                    or {"batch_kwargs", "expectation_suite_names"}.issubset(
                         set(
                             itertools.chain.from_iterable(
                                 item.keys() for item in batches
@@ -164,3 +177,28 @@ class CheckpointStore(ConfigurationStore):
         if isinstance(checkpoint_ref, GeCloudIdAwareRef):
             ge_cloud_id = checkpoint_ref.ge_cloud_id
             checkpoint.ge_cloud_id = uuid.UUID(ge_cloud_id)
+
+    def create(self, checkpoint_config: CheckpointConfig) -> Optional[DataContextKey]:
+        """Create a checkpoint config in the store using a store_backend-specific key.
+
+        Args:
+            checkpoint_config: Config containing the checkpoint name.
+
+        Returns:
+            None unless using GeCloudStoreBackend and if so the GeCloudResourceRef which contains the id
+            which was used to create the config in the backend.
+        """
+        # CheckpointConfig not an AbstractConfig??
+        # mypy error: incompatible type "CheckpointConfig"; expected "AbstractConfig"
+        key: DataContextKey = self._build_key_from_config(checkpoint_config)  # type: ignore[arg-type]
+
+        # Make two separate requests to set and get in order to obtain any additional
+        # values that may have been added to the config by the StoreBackend (i.e. object ids)
+        ref: Optional[GeCloudResourceRef] = self.set(key, checkpoint_config)  # type: ignore[func-returns-value]
+        if ref:
+            assert isinstance(key, GeCloudIdentifier)
+            key.ge_cloud_id = ref.ge_cloud_id
+
+        config = self.get(key=key)
+
+        return config
