@@ -4,6 +4,7 @@ import copy
 from typing import List, Optional, Union
 
 from great_expectations.core.data_context_key import DataContextVariableKey
+from great_expectations.core.serializer import AbstractConfigSerializer
 from great_expectations.data_context.store.store import Store
 from great_expectations.data_context.store.store_backend import StoreBackend
 from great_expectations.data_context.types.base import (
@@ -24,11 +25,13 @@ class DatasourceStore(Store):
 
     def __init__(
         self,
+        serializer: AbstractConfigSerializer,
         store_name: Optional[str] = None,
         store_backend: Optional[dict] = None,
         runtime_environment: Optional[dict] = None,
     ) -> None:
         self._schema = DatasourceConfigSchema()
+        self._serializer = serializer
         super().__init__(
             store_backend=store_backend,
             runtime_environment=runtime_environment,
@@ -64,14 +67,11 @@ class DatasourceStore(Store):
         """
         return self._store_backend.remove_key(key.to_tuple())
 
-    def serialize(self, value: DatasourceConfig) -> Union[str, DatasourceConfig]:
+    def serialize(self, value: DatasourceConfig) -> Union[str, dict, DatasourceConfig]:
         """
         See parent 'Store.serialize()' for more information
         """
-        if self.ge_cloud_mode:
-            # GeCloudStoreBackend expects a json str
-            return self._schema.dump(value)
-        return value
+        return self._serializer.serialize(value)
 
     def deserialize(self, value: Union[dict, DatasourceConfig]) -> DatasourceConfig:
         """
