@@ -19,7 +19,7 @@ class MetricStore(Store):
     A MetricStore stores ValidationMetric information to be used between runs.
     """
 
-    _key_class = ValidationMetricIdentifier
+    _key_class = ValidationMetricIdentifier  # type: ignore[assignment]
 
     def __init__(self, store_backend=None, store_name=None) -> None:
         if store_backend is not None:
@@ -60,10 +60,10 @@ class MetricStore(Store):
         # Values must be json serializable since they must be inputs to expectation configurations
         ensure_json_serializable(value)
 
-    def serialize(self, key, value):
+    def serialize(self, value):
         return json.dumps({"value": value})
 
-    def deserialize(self, key, value):
+    def deserialize(self, value):
         if value:
             return json.loads(value)["value"]
 
@@ -104,7 +104,7 @@ class EvaluationParameterStore(MetricStore):
         params = {}
         for k in self._store_backend.list_keys(run_id.to_tuple()):
             key = self.tuple_to_key(k)
-            params[key.to_evaluation_parameter_urn()] = self.get(key)
+            params[key.to_evaluation_parameter_urn()] = self.get(key)  # type: ignore[attr-defined]
         return params
 
     @property
