@@ -14,6 +14,8 @@ KNOWN_EXTENSIONS = [
     ".csv",
     ".tsv",
     ".parquet",
+    ".parq",
+    ".pqt",
     ".xls",
     ".xlsx",
     ".json",
@@ -210,8 +212,7 @@ class SubdirReaderBatchKwargsGenerator(BatchKwargsGenerator):
 
     def _get_iterator(self, data_asset_name, reader_options=None, limit=None):
         logger.debug(
-            "Beginning SubdirReaderBatchKwargsGenerator _get_iterator for data_asset_name: %s"
-            % data_asset_name
+            f"Beginning SubdirReaderBatchKwargsGenerator _get_iterator for data_asset_name: {data_asset_name}"
         )
         # If the data asset is a file, then return the path.
         # Otherwise, use files in a subdir as batches
