@@ -59,6 +59,7 @@ class ConfiguredAssetAzureDataConnector(ConfiguredAssetFilePathDataConnector):
         delimiter: str = "/",
         azure_options: Optional[dict] = None,
         batch_spec_passthrough: Optional[dict] = None,
+        id_: Optional[str] = None,
     ) -> None:
         """
         ConfiguredAssetDataConnector for connecting to Azure.
@@ -80,6 +81,7 @@ class ConfiguredAssetAzureDataConnector(ConfiguredAssetFilePathDataConnector):
 
         super().__init__(
             name=name,
+            id_=id_,
             datasource_name=datasource_name,
             execution_engine=execution_engine,
             assets=assets,
