@@ -45,6 +45,7 @@ class DataConnector:
         datasource_name: str,
         execution_engine: ExecutionEngine,
         batch_spec_passthrough: Optional[dict] = None,
+        id_: Optional[str] = None,
     ) -> None:
         """
         Base class for DataConnectors
@@ -61,6 +62,7 @@ class DataConnector:
             )
 
         self._name = name
+        self._id = id_
         self._datasource_name = datasource_name
         self._execution_engine = execution_engine
 
@@ -140,7 +142,7 @@ class DataConnector:
             batch_spec_passthrough.update(batch_definition.batch_spec_passthrough)
 
         batch_spec_params.update(batch_spec_passthrough)
-        batch_spec: BatchSpec = BatchSpec(**batch_spec_params)
+        batch_spec = BatchSpec(**batch_spec_params)
         return batch_spec
 
     def _refresh_data_references_cache(
@@ -374,7 +376,7 @@ class DataConnector:
         # Note: get_batch_data_and_metadata will have loaded the data into the currently-defined execution engine.
         # Consequently, when we build a Validator, we do not need to specifically load the batch into it to
         # resolve metrics.
-        validator: Validator = Validator(execution_engine=batch_data.execution_engine)
+        validator = Validator(execution_engine=batch_data.execution_engine)
         data: Any = validator.get_metric(
             metric=MetricConfiguration(
                 metric_name="table.head",
