@@ -80,6 +80,7 @@ def batch_definition_matches_batch_request(
         if batch_filter_parameters:
             if not isinstance(batch_filter_parameters, dict):
                 return False
+
             for key in batch_filter_parameters.keys():
                 if not (
                     key in batch_definition.batch_identifiers
@@ -91,6 +92,7 @@ def batch_definition_matches_batch_request(
     if batch_request.batch_identifiers:
         if not isinstance(batch_request.batch_identifiers, dict):
             return False
+
         for key in batch_request.batch_identifiers.keys():
             if not (
                 key in batch_definition.batch_identifiers
@@ -153,7 +155,7 @@ def convert_data_reference_string_to_batch_identifiers_using_regex(
         )
     else:
         groups: list = list(matches.groups())
-        batch_identifiers: IDDict = IDDict(dict(zip(group_names, groups)))
+        batch_identifiers = IDDict(dict(zip(group_names, groups)))
 
     # TODO: <Alex>Accommodating "data_asset_name" inside batch_identifiers (e.g., via "group_names") is problematic; we need a better mechanism.</Alex>
     # TODO: <Alex>Update: Approach -- we can differentiate "def map_data_reference_string_to_batch_definition_list_using_regex(()" methods between ConfiguredAssetFilesystemDataConnector and InferredAssetFilesystemDataConnector so that IDDict never needs to include data_asset_name. (ref: https://superconductivedata.slack.com/archives/C01C0BVPL5Q/p1603843413329400?thread_ts=1603842470.326800&cid=C01C0BVPL5Q)</Alex>
