@@ -2,6 +2,7 @@ import importlib
 import itertools
 import json
 from collections.abc import Iterable
+from typing import Any, Dict, List, Union
 
 from great_expectations.marshmallow__shade import ValidationError
 
@@ -15,13 +16,13 @@ class GreatExpectationsError(Exception):
 class GreatExpectationsValidationError(ValidationError, GreatExpectationsError):
     def __init__(self, message, validation_error=None) -> None:
         self.message = message
-        self.messages = None
+        self.messages: Union[List[str], List[Any], Dict] = []
         if validation_error is not None:
             self.messages = validation_error.messages
 
     def __str__(self) -> str:
         if self.message is None:
-            return self.messages
+            return str(self.messages)
         return self.message
 
 
@@ -120,13 +121,13 @@ class ProfilerError(GreatExpectationsError):
 
 
 class ProfilerConfigurationError(ProfilerError):
-    """A configuration error for a profiler."""
+    """A configuration error for a "RuleBasedProfiler" class."""
 
     pass
 
 
 class ProfilerExecutionError(ProfilerError):
-    """A runtime error for a profiler."""
+    """A runtime error for a "RuleBasedProfiler" class."""
 
     pass
 
@@ -135,6 +136,22 @@ class ProfilerNotFoundError(ProfilerError):
     pass
 
 
+class DataAssistantError(ProfilerError):
+    pass
+
+
+class DataAssistantExecutionError(DataAssistantError):
+    """A runtime error for a "DataAssistant" class."""
+
+    pass
+
+
+class DataAssistantResultExecutionError(DataAssistantError):
+    """A runtime error for a "DataAssistantResult" class."""
+
+    pass
+
+
 class InvalidConfigError(DataContextError):
     def __init__(self, message) -> None:
         self.message = message
@@ -287,7 +304,7 @@ class PluginClassNotFoundError(DataContextError, AttributeError):
 
 class ClassInstantiationError(GreatExpectationsError):
     def __init__(self, module_name, package_name, class_name) -> None:
-        module_spec = importlib.util.find_spec(module_name, package=package_name)
+        module_spec = importlib.util.find_spec(module_name, package=package_name)  # type: ignore[attr-defined]
         if not module_spec:
             if not package_name:
                 package_name = ""
