@@ -1,6 +1,9 @@
 import copy
 import datetime
+import hashlib
 import logging
+import math
+import os
 import random
 import re
 import string
@@ -14,6 +17,10 @@ from great_expectations._version import get_versions  # isort:skip
 __version__ = get_versions()["version"]  # isort:skip
 
 from great_expectations.core.usage_statistics.events import UsageStatsEvents
+from great_expectations.core.util import convert_to_json_serializable
+from great_expectations.execution_engine.bundled_metric_configuration import (
+    BundledMetricConfiguration,
+)
 from great_expectations.execution_engine.split_and_sample.sqlalchemy_data_sampler import (
     SqlAlchemyDataSampler,
 )
@@ -30,7 +37,6 @@ from great_expectations.core.batch_spec import (
     RuntimeQueryBatchSpec,
     SqlAlchemyDatasourceBatchSpec,
 )
-from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.data_context.types.base import ConcurrencyConfig
 from great_expectations.exceptions import (
     DatasourceKeyPairAuthBadPassphraseError,
@@ -258,6 +264,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
         self._connection_string = connection_string
         self._url = url
         self._create_temp_table = create_temp_table
+        os.environ["SF_PARTNER"] = "great_expectations_oss"
 
         if engine is not None:
             if credentials is not None:
@@ -289,14 +296,14 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                 )
 
         # these are two backends where temp_table_creation is not supported we set the default value to False.
-        if self.engine.dialect.name.lower() in [
+        if self.dialect_name in [
             "trino",
             "awsathena",  # WKS 202201 - AWS Athena currently doesn't support temp_tables.
         ]:
             self._create_temp_table = False
 
         # Get the dialect **for purposes of identifying types**
-        if self.engine.dialect.name.lower() in [
+        if self.dialect_name in [
             "postgresql",
             "mysql",
             "sqlite",
@@ -308,24 +315,24 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                 module_name=f"sqlalchemy.dialects.{self.engine.dialect.name}"
             )
 
-        elif self.engine.dialect.name.lower() == "snowflake":
+        elif self.dialect_name == "snowflake":
             self.dialect_module = import_library_module(
                 module_name="snowflake.sqlalchemy.snowdialect"
             )
-        elif self.engine.dialect.name.lower() == "dremio":
+        elif self.dialect_name == "dremio":
             # WARNING: Dremio Support is experimental, functionality is not fully under test
             self.dialect_module = import_library_module(
                 module_name="sqlalchemy_dremio.pyodbc"
             )
-        elif self.engine.dialect.name.lower() == "redshift":
+        elif self.dialect_name == "redshift":
             self.dialect_module = import_library_module(
                 module_name="sqlalchemy_redshift.dialect"
             )
-        elif self.engine.dialect.name.lower() == "bigquery":
+        elif self.dialect_name == "bigquery":
             self.dialect_module = import_library_module(
                 module_name=_BIGQUERY_MODULE_NAME
             )
-        elif self.engine.dialect.name.lower() == "teradatasql":
+        elif self.dialect_name == "teradatasql":
             # WARNING: Teradata Support is experimental, functionality is not fully under test
             self.dialect_module = import_library_module(
                 module_name="teradatasqlalchemy.dialect"
@@ -338,7 +345,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
         # depending on the backend. This will need to be cleaned up in an upcoming refactor, so that Engine and
         # Connection can be handled separately.
         self._engine_backup = None
-        if self.engine and self.engine.dialect.name.lower() in [
+        if self.engine and self.dialect_name in [
             "sqlite",
             "mssql",
             "snowflake",
@@ -347,6 +354,18 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
             self._engine_backup = self.engine
             # sqlite/mssql temp tables only persist within a connection so override the engine
             self.engine = self.engine.connect()
+            if self._engine_backup.dialect.name.lower() == "sqlite" and not isinstance(
+                self._engine_backup, sa.engine.base.Connection
+            ):
+                raw_connection = self._engine_backup.raw_connection()
+                raw_connection.create_function("sqrt", 1, lambda x: math.sqrt(x))
+                raw_connection.create_function(
+                    "md5",
+                    2,
+                    lambda x, d: hashlib.md5(str(x).encode("utf-8")).hexdigest()[
+                        -1 * d :
+                    ],
+                )
 
         # Send a connect event to provide dialect type
         if data_context is not None and getattr(
@@ -378,7 +397,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
         self._config.update(kwargs)
         filter_properties_dict(properties=self._config, clean_falsy=True, inplace=True)
 
-        self._data_splitter = SqlAlchemyDataSplitter()
+        self._data_splitter = SqlAlchemyDataSplitter(dialect=self.dialect_name)
         self._data_sampler = SqlAlchemyDataSampler()
 
     @property
@@ -436,8 +455,10 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
         engine = sa.create_engine(options, **create_engine_kwargs)
         return engine
 
+    @staticmethod
     def _get_sqlalchemy_key_pair_auth_url(
-        self, drivername: str, credentials: dict
+        drivername: str,
+        credentials: dict,
     ) -> Tuple["sa.engine.url.URL", Dict]:
         """
         Utilizing a private key path and a passphrase in a given credentials dictionary, attempts to encode the provided
@@ -500,7 +521,9 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
         Returns:
             An SqlAlchemy table/column(s) (the selectable object for obtaining data on which to compute)
         """
-        batch_id = domain_kwargs.get("batch_id")
+        data_object: SqlAlchemyBatchData
+
+        batch_id: Optional[str] = domain_kwargs.get("batch_id")
         if batch_id is None:
             # We allow no batch id specified if there is only one batch
             if self.active_batch_data:
@@ -522,6 +545,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
             # TODO: Add logic to handle record_set_name once implemented
             # (i.e. multiple record sets (tables) in one batch
             if domain_kwargs["table"] != data_object.selectable.name:
+                # noinspection PyProtectedMember
                 selectable = sa.Table(
                     domain_kwargs["table"],
                     sa.MetaData(),
@@ -854,44 +878,59 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
 
     def resolve_metric_bundle(
         self,
-        metric_fn_bundle: Iterable[Tuple[MetricConfiguration, Any, dict, dict]],
+        metric_fn_bundle: Iterable[BundledMetricConfiguration],
     ) -> Dict[Tuple[str, str, str], Any]:
         """For every metric in a set of Metrics to resolve, obtains necessary metric keyword arguments and builds
         bundles of the metrics into one large query dictionary so that they are all executed simultaneously. Will fail
         if bundling the metrics together is not possible.
 
             Args:
-                metric_fn_bundle (Iterable[Tuple[MetricConfiguration, Callable, dict]): \
-                    A Dictionary containing a MetricProvider's MetricConfiguration (its unique identifier), its metric provider function
-                    (the function that actually executes the metric), and the arguments to pass to the metric provider function.
-                    A dictionary of metrics defined in the registry and corresponding arguments
+                metric_fn_bundle (Iterable[BundledMetricConfiguration]): \
+                    "BundledMetricConfiguration" contains MetricProvider's MetricConfiguration (its unique identifier),
+                    its metric provider function (the function that actually executes the metric), and arguments to pass
+                    to metric provider function (dictionary of metrics defined in registry and corresponding arguments).
 
             Returns:
-                A dictionary of metric names and their corresponding now-queried values.
+                A dictionary of "MetricConfiguration" IDs and their corresponding now-queried (fully resolved) values.
         """
-        resolved_metrics = {}
+        resolved_metrics: Dict[Tuple[str, str, str], Any] = {}
+
+        res: List[Row]
 
         # We need a different query for each domain (where clause).
         queries: Dict[Tuple, dict] = {}
-        for (
-            metric_to_resolve,
-            engine_fn,
-            compute_domain_kwargs,
-            accessor_domain_kwargs,
-            metric_provider_kwargs,
-        ) in metric_fn_bundle:
+
+        query: dict
+
+        domain_id: Tuple[str, str, str]
+
+        bundled_metric_configuration: BundledMetricConfiguration
+        for bundled_metric_configuration in metric_fn_bundle:
+            bundled_metric_configuration: BundledMetricConfiguration
+            metric_to_resolve: MetricConfiguration = (
+                bundled_metric_configuration.metric_configuration
+            )
+            metric_fn: Any = bundled_metric_configuration.metric_fn
+            compute_domain_kwargs: dict = (
+                bundled_metric_configuration.compute_domain_kwargs
+            )
+
             if not isinstance(compute_domain_kwargs, IDDict):
                 compute_domain_kwargs = IDDict(compute_domain_kwargs)
-            domain_id = compute_domain_kwargs.to_id()
+
+            domain_id = IDDict.convert_dictionary_to_id_dict(
+                data=convert_to_json_serializable(data=compute_domain_kwargs)
+            ).to_id()
             if domain_id not in queries:
                 queries[domain_id] = {
                     "select": [],
                     "ids": [],
                     "domain_kwargs": compute_domain_kwargs,
                 }
+
             if self.engine.dialect.name == "clickhouse":
                 queries[domain_id]["select"].append(
-                    engine_fn.label(
+                    metric_fn.label(
                         metric_to_resolve.metric_name.join(
                             random.choices(string.ascii_lowercase, k=2)
                         )
@@ -899,15 +938,19 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                 )
             else:
                 queries[domain_id]["select"].append(
-                    engine_fn.label(metric_to_resolve.metric_name)
+                    metric_fn.label(metric_to_resolve.metric_name)
                 )
+
             queries[domain_id]["ids"].append(metric_to_resolve.id)
+
         for query in queries.values():
-            domain_kwargs = query["domain_kwargs"]
-            selectable = self.get_domain_records(
+            domain_kwargs: dict = query["domain_kwargs"]
+            selectable: Any = self.get_domain_records(
                 domain_kwargs=domain_kwargs,
             )
+
             assert len(query["select"]) == len(query["ids"])
+
             try:
                 """
                 If a custom query is passed, selectable will be TextClause and not formatted
@@ -924,8 +967,9 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                     res = self.engine.execute(
                         sa.select(query["select"]).select_from(selectable)
                     ).fetchall()
+
                 logger.debug(
-                    f"SqlAlchemyExecutionEngine computed {len(res[0])} metrics on domain_id {IDDict(domain_kwargs).to_id()}"
+                    f"SqlAlchemyExecutionEngine computed {len(res[0])} metrics on domain_id {IDDict.convert_dictionary_to_id_dict(data=convert_to_json_serializable(data=domain_kwargs)).to_id()}"
                 )
             except OperationalError as oe:
                 exception_message: str = "An SQL execution Exception occurred.  "
@@ -933,14 +977,22 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                 exception_message += f'{type(oe).__name__}: "{str(oe)}".  Traceback: "{exception_traceback}".'
                 logger.error(exception_message)
                 raise ExecutionEngineError(message=exception_message)
+
             assert (
                 len(res) == 1
             ), "all bundle-computed metrics must be single-value statistics"
             assert len(query["ids"]) == len(
                 res[0]
             ), "unexpected number of metrics returned"
-            for idx, id in enumerate(query["ids"]):
-                resolved_metrics[id] = convert_to_json_serializable(res[0][idx])
+
+            idx: int
+            metric_id: Tuple[str, str, str]
+            for idx, metric_id in enumerate(query["ids"]):
+                # Converting SQL query execution results into JSON-serializable format produces simple data types,
+                # amenable for subsequent post-processing by higher-level "Metric" and "Expectation" layers.
+                resolved_metrics[metric_id] = convert_to_json_serializable(
+                    data=res[0][idx]
+                )
 
         return resolved_metrics
 
@@ -988,7 +1040,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
         Returns:
             List of row results.
         """
-        if self.engine.dialect.name.lower() == "awsathena":
+        if self.dialect_name == "awsathena":
             # Note: Athena does not support casting to string, only to varchar
             # but sqlalchemy currently generates a query as `CAST(colname AS STRING)` instead
             # of `CAST(colname AS VARCHAR)` with other dialects.
@@ -1036,7 +1088,10 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
             )
 
         else:
-            split_clause = True
+            if self.dialect_name == "sqlite":
+                split_clause = sa.text("1 = 1")
+            else:
+                split_clause = sa.true()
 
         table_name: str = batch_spec["table_name"]
         sampling_method: Optional[str] = batch_spec.get("sampling_method")
@@ -1067,6 +1122,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                         )
                     )
                 )
+
         return (
             sa.select("*")
             .select_from(
@@ -1088,7 +1144,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
             )
 
         batch_data: Optional[SqlAlchemyBatchData] = None
-        batch_markers: BatchMarkers = BatchMarkers(
+        batch_markers = BatchMarkers(
             {
                 "ge_load_time": datetime.datetime.now(datetime.timezone.utc).strftime(
                     "%Y%m%dT%H%M%S.%fZ"
@@ -1129,15 +1185,9 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                 source_schema_name=source_schema_name,
             )
         elif isinstance(batch_spec, SqlAlchemyDatasourceBatchSpec):
-            if self.engine.dialect.name.lower() == "oracle":
-                selectable: str = self._build_selectable_from_batch_spec(
-                    batch_spec=batch_spec
-                )
-            else:
-                selectable: Selectable = self._build_selectable_from_batch_spec(
-                    batch_spec=batch_spec
-                )
-
+            selectable: Union[Selectable, str] = self._build_selectable_from_batch_spec(
+                batch_spec=batch_spec
+            )
             batch_data = SqlAlchemyBatchData(
                 execution_engine=self,
                 selectable=selectable,
