@@ -1,4 +1,4 @@
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 
 import numpy as np
 
@@ -13,6 +13,7 @@ from great_expectations.expectations.metrics.column_aggregate_metric_provider im
     ColumnAggregateMetricProvider,
 )
 from great_expectations.expectations.metrics.metric_provider import metric_value
+from great_expectations.util import convert_ndarray_to_datetime_dtype_best_effort
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
 
@@ -36,7 +37,9 @@ class ColumnPartition(ColumnAggregateMetricProvider):
     ):
         bins = metric_value_kwargs.get("bins", cls.default_kwarg_values["bins"])
         n_bins = metric_value_kwargs.get("n_bins", cls.default_kwarg_values["n_bins"])
-        return _get_column_partition_using_metrics(bins, n_bins, metrics)
+        return _get_column_partition_using_metrics(
+            bins=bins, n_bins=n_bins, _metrics=metrics
+        )
 
     @metric_value(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(
@@ -49,7 +52,9 @@ class ColumnPartition(ColumnAggregateMetricProvider):
     ):
         bins = metric_value_kwargs.get("bins", cls.default_kwarg_values["bins"])
         n_bins = metric_value_kwargs.get("n_bins", cls.default_kwarg_values["n_bins"])
-        return _get_column_partition_using_metrics(bins, n_bins, metrics)
+        return _get_column_partition_using_metrics(
+            bins=bins, n_bins=n_bins, _metrics=metrics
+        )
 
     @metric_value(engine=SparkDFExecutionEngine)
     def _spark(
@@ -62,7 +67,9 @@ class ColumnPartition(ColumnAggregateMetricProvider):
     ):
         bins = metric_value_kwargs.get("bins", cls.default_kwarg_values["bins"])
         n_bins = metric_value_kwargs.get("n_bins", cls.default_kwarg_values["n_bins"])
-        return _get_column_partition_using_metrics(bins, n_bins, metrics)
+        return _get_column_partition_using_metrics(
+            bins=bins, n_bins=n_bins, _metrics=metrics
+        )
 
     @classmethod
     def _get_evaluation_dependencies(
@@ -122,28 +129,111 @@ class ColumnPartition(ColumnAggregateMetricProvider):
         return dependencies
 
 
-def _get_column_partition_using_metrics(bins, n_bins, _metrics):
+def _get_column_partition_using_metrics(bins: int, n_bins: int, _metrics: dict) -> list:
     if bins == "uniform":
         min_ = _metrics["column.min"]
         max_ = _metrics["column.max"]
-        # PRECISION NOTE: some implementations of quantiles could produce
-        # varying levels of precision (e.g. a NUMERIC column producing
-        # Decimal from a SQLAlchemy source, so we cast to float for numpy)
-        bins = np.linspace(start=float(min_), stop=float(max_), num=n_bins + 1).tolist()
+
+        original_ndarray_is_datetime_type: bool
+        conversion_ndarray_to_datetime_type_performed: bool
+        min_max_values: np.ndaarray
+        (
+            original_ndarray_is_datetime_type,
+            conversion_ndarray_to_datetime_type_performed,
+            min_max_values,
+        ) = convert_ndarray_to_datetime_dtype_best_effort(
+            data=[min_, max_],
+            parse_strings_as_datetimes=True,
+        )
+        ndarray_is_datetime_type: bool = (
+            original_ndarray_is_datetime_type
+            or conversion_ndarray_to_datetime_type_performed
+        )
+        min_ = min_max_values[0]
+        max_ = min_max_values[1]
+
+        bins = _determine_bins_using_proper_units(
+            ndarray_is_datetime_type=ndarray_is_datetime_type,
+            n_bins=n_bins,
+            min_=min_,
+            max_=max_,
+        )
     elif bins in ["ntile", "quantile", "percentile"]:
         bins = _metrics["column.quantile_values"]
     elif bins == "auto":
         # Use the method from numpy histogram_bin_edges
         nonnull_count = _metrics["column_values.nonnull.count"]
-        sturges = np.log2(nonnull_count + 1)
+        sturges = np.log2(1.0 * nonnull_count + 1.0)
         min_, _25, _75, max_ = _metrics["column.quantile_values"]
-        iqr = _75 - _25
-        if iqr < 1e-10:  # Consider IQR 0 and do not use variance-based estimator
-            n_bins = sturges
+
+        original_ndarray_is_datetime_type: bool
+        conversion_ndarray_to_datetime_type_performed: bool
+        box_plot_values: np.ndaarray
+        (
+            original_ndarray_is_datetime_type,
+            conversion_ndarray_to_datetime_type_performed,
+            box_plot_values,
+        ) = convert_ndarray_to_datetime_dtype_best_effort(
+            data=[min_, _25, _75, max_],
+            parse_strings_as_datetimes=True,
+        )
+        ndarray_is_datetime_type: bool = (
+            original_ndarray_is_datetime_type
+            or conversion_ndarray_to_datetime_type_performed
+        )
+        min_ = box_plot_values[0]
+        _25 = box_plot_values[1]
+        _75 = box_plot_values[2]
+        max_ = box_plot_values[3]
+
+        if ndarray_is_datetime_type:
+            iqr = _75.timestamp() - _25.timestamp()
+            min_as_float_ = min_.timestamp()
+            max_as_float_ = max_.timestamp()
         else:
-            fd = (2 * float(iqr)) / (nonnull_count ** (1 / 3))
-            n_bins = max(int(np.ceil(sturges)), int(np.ceil(float(max_ - min_) / fd)))
-        bins = np.linspace(start=float(min_), stop=float(max_), num=n_bins + 1).tolist()
+            iqr = _75 - _25
+            min_as_float_ = min_
+            max_as_float_ = max_
+
+        if iqr < 1.0e-10:  # Consider IQR 0 and do not use variance-based estimator
+            n_bins = int(np.ceil(sturges))
+        else:
+            if nonnull_count == 0:
+                n_bins = 0
+            else:
+                fd = (2 * float(iqr)) / (nonnull_count ** (1.0 / 3.0))
+                n_bins = max(
+                    int(np.ceil(sturges)),
+                    int(np.ceil(float(max_as_float_ - min_as_float_) / fd)),
+                )
+
+        bins = _determine_bins_using_proper_units(
+            ndarray_is_datetime_type=ndarray_is_datetime_type,
+            n_bins=n_bins,
+            min_=min_,
+            max_=max_,
+        )
     else:
         raise ValueError("Invalid parameter for bins argument")
+
+    return bins
+
+
+def _determine_bins_using_proper_units(
+    ndarray_is_datetime_type: bool, n_bins: int, min_: Any, max_: Any
+) -> List[Any]:
+    if ndarray_is_datetime_type:
+        if n_bins == 0:
+            bins = [min_]
+        else:
+            delta_t = (max_ - min_) / n_bins
+            bins = []
+            for idx in range(n_bins + 1):
+                bins.append(min_ + idx * delta_t)
+    else:
+        # PRECISION NOTE: some implementations of quantiles could produce
+        # varying levels of precision (e.g. a NUMERIC column producing
+        # Decimal from a SQLAlchemy source, so we cast to float for numpy)
+        bins = np.linspace(start=float(min_), stop=float(max_), num=n_bins + 1).tolist()
+
     return bins
