@@ -13,6 +13,7 @@ from great_expectations.expectations.metrics.map_metric_provider import (
     column_condition_partial,
     column_function_partial,
 )
+from great_expectations.util import pandas_series_between_inclusive
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
 
@@ -110,8 +111,8 @@ class ColumnValuesValueLength(ColumnMapMetricProvider):
                     column_lengths < max_value
                 )
             elif not strict_min and not strict_max:
-                metric_series = column_lengths.between(
-                    min_value, max_value, inclusive=True
+                metric_series = pandas_series_between_inclusive(
+                    series=column_lengths, min_value=min_value, max_value=max_value
                 )
         elif min_value is None and max_value is not None:
             if strict_max:
