@@ -132,6 +132,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
                 metric_name=metric_name,
                 metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
                 metric_value_kwargs=None,
+                single_batch_mode=False,
                 enforce_numeric_metric=False,
                 replace_nan_with_zero=False,
                 reduce_scalar_metric=True,
@@ -291,6 +292,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
                 metric_name=metric_name,
                 metric_domain_kwargs=metric_domain_kwargs,
                 metric_value_kwargs=metric_value_kwargs,
+                single_batch_mode=False,
                 enforce_numeric_metric=True,
                 replace_nan_with_zero=True,
                 reduce_scalar_metric=True,
@@ -464,7 +466,6 @@ class DataAssistant(metaclass=MetaDataAssistant):
 
         data_assistant_result = DataAssistantResult(
             _batch_id_to_batch_identifier_display_name_map=self._batch_id_to_batch_identifier_display_name_map(),
-            execution_time=0.0,
             _usage_statistics_handler=usage_statistics_handler,
         )
         run_profiler_on_data(
@@ -613,7 +614,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
 
 @measure_execution_time(
     execution_time_holder_object_reference_name="data_assistant_result",
-    execution_time_property_name="execution_time",
+    execution_time_property_name="profiler_execution_time",
     pretty_print=False,
 )
 def run_profiler_on_data(
@@ -668,7 +669,9 @@ configuration included.
     )
     result: DataAssistantResult = data_assistant_result
     result.profiler_config = profiler.config
-    result.profiler_execution_time = rule_based_profiler_result.execution_time
+    result.rule_domain_builder_execution_time = (
+        rule_based_profiler_result.rule_domain_builder_execution_time
+    )
     result.rule_execution_time = rule_based_profiler_result.rule_execution_time
     result.metrics_by_domain = data_assistant.get_metrics_by_domain()
     result.expectation_configurations = (
