@@ -14,12 +14,9 @@ from tests.cli.utils import assert_no_logging_messages_or_tracebacks
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
 def test_cli_datasource_list_on_project_with_no_datasources(
-    mock_emit, caplog, monkeypatch, empty_data_context, filesystem_csv_2
+    mock_emit, caplog, monkeypatch, empty_data_context_stats_enabled, filesystem_csv_2
 ):
-    monkeypatch.delenv(
-        "GE_USAGE_STATS", raising=False
-    )  # Undo the project-wide test default
-    context: DataContext = empty_data_context
+    context: DataContext = empty_data_context_stats_enabled
 
     runner = CliRunner(mix_stderr=False)
     monkeypatch.chdir(os.path.dirname(context.root_directory))
@@ -120,13 +117,10 @@ def test_cli_datasource_new(
     mock_emit,
     caplog,
     monkeypatch,
-    empty_data_context,
+    empty_data_context_stats_enabled,
     filesystem_csv_2,
 ):
-    monkeypatch.delenv(
-        "GE_USAGE_STATS", raising=False
-    )  # Undo the project-wide test default
-    context = empty_data_context
+    context = empty_data_context_stats_enabled
     root_dir = context.root_directory
     assert context.list_datasources() == []
 
@@ -194,32 +188,39 @@ def test_cli_datasource_new(
     assert len(context.list_datasources()) == 1
     assert context.list_datasources() == [
         {
-            "execution_engine": {
-                "class_name": "PandasExecutionEngine",
-                "module_name": "great_expectations.execution_engine",
-            },
             "class_name": "Datasource",
-            "module_name": "great_expectations.datasource",
             "data_connectors": {
                 "default_inferred_data_connector_name": {
-                    "module_name": "great_expectations.datasource.data_connector",
+                    "base_directory": "../../filesystem_csv_2",
+                    "class_name": "InferredAssetFilesystemDataConnector",
                     "default_regex": {
                         "group_names": ["data_asset_name"],
                         "pattern": "(.*)",
                     },
-                    "base_directory": "../../filesystem_csv_2",
+                    "base_directory": "../../test_cli_datasource_new0/filesystem_csv_2",
                     "class_name": "InferredAssetFilesystemDataConnector",
+                    "module_name": "great_expectations.datasource.data_connector",
                 },
                 "default_runtime_data_connector_name": {
-                    "module_name": "great_expectations.datasource.data_connector",
-                    "batch_identifiers": ["default_identifier_name"],
+                    "assets": {
+                        "my_runtime_asset_name": {
+                            "batch_identifiers": ["runtime_batch_identifier_name"],
+                            "class_name": "Asset",
+                            "module_name": "great_expectations.datasource.data_connector.asset",
+                        }
+                    },
                     "class_name": "RuntimeDataConnector",
+                    "module_name": "great_expectations.datasource.data_connector",
                 },
             },
+            "execution_engine": {
+                "class_name": "PandasExecutionEngine",
+                "module_name": "great_expectations.execution_engine",
+            },
+            "module_name": "great_expectations.datasource",
             "name": "my_datasource",
         }
     ]
-
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
 
@@ -232,13 +233,10 @@ def test_cli_datasource_new_no_jupyter_writes_notebook(
     mock_emit,
     caplog,
     monkeypatch,
-    empty_data_context,
+    empty_data_context_stats_enabled,
     filesystem_csv_2,
 ):
-    monkeypatch.delenv(
-        "GE_USAGE_STATS", raising=False
-    )  # Undo the project-wide test default
-    context = empty_data_context
+    context = empty_data_context_stats_enabled
     root_dir = context.root_directory
     assert context.list_datasources() == []
 
@@ -340,28 +338,34 @@ def test_cli_datasource_new_with_name_param(
     assert len(context.list_datasources()) == 1
     assert context.list_datasources() == [
         {
-            "module_name": "great_expectations.datasource",
-            "execution_engine": {
-                "module_name": "great_expectations.execution_engine",
-                "class_name": "PandasExecutionEngine",
-            },
+            "class_name": "Datasource",
             "data_connectors": {
                 "default_inferred_data_connector_name": {
+                    "base_directory": "../../filesystem_csv_2",
+                    "class_name": "InferredAssetFilesystemDataConnector",
                     "default_regex": {
                         "group_names": ["data_asset_name"],
                         "pattern": "(.*)",
                     },
                     "module_name": "great_expectations.datasource.data_connector",
-                    "class_name": "InferredAssetFilesystemDataConnector",
-                    "base_directory": "../../filesystem_csv_2",
                 },
                 "default_runtime_data_connector_name": {
-                    "batch_identifiers": ["default_identifier_name"],
-                    "module_name": "great_expectations.datasource.data_connector",
+                    "assets": {
+                        "my_runtime_asset_name": {
+                            "batch_identifiers": ["runtime_batch_identifier_name"],
+                            "class_name": "Asset",
+                            "module_name": "great_expectations.datasource.data_connector.asset",
+                        }
+                    },
                     "class_name": "RuntimeDataConnector",
+                    "module_name": "great_expectations.datasource.data_connector",
                 },
             },
-            "class_name": "Datasource",
+            "execution_engine": {
+                "class_name": "PandasExecutionEngine",
+                "module_name": "great_expectations.execution_engine",
+            },
+            "module_name": "great_expectations.datasource",
             "name": "foo",
         }
     ]
@@ -414,28 +418,34 @@ def test_cli_datasource_new_from_misc_directory(
 
     assert context.list_datasources() == [
         {
-            "module_name": "great_expectations.datasource",
-            "execution_engine": {
-                "module_name": "great_expectations.execution_engine",
-                "class_name": "PandasExecutionEngine",
-            },
             "class_name": "Datasource",
             "data_connectors": {
                 "default_inferred_data_connector_name": {
-                    "module_name": "great_expectations.datasource.data_connector",
-                    "class_name": "InferredAssetFilesystemDataConnector",
                     "base_directory": "../../filesystem_csv_2",
+                    "class_name": "InferredAssetFilesystemDataConnector",
                     "default_regex": {
                         "group_names": ["data_asset_name"],
                         "pattern": "(.*)",
                     },
+                    "module_name": "great_expectations.datasource.data_connector",
                 },
                 "default_runtime_data_connector_name": {
-                    "module_name": "great_expectations.datasource.data_connector",
-                    "batch_identifiers": ["default_identifier_name"],
+                    "assets": {
+                        "my_runtime_asset_name": {
+                            "batch_identifiers": ["runtime_batch_identifier_name"],
+                            "class_name": "Asset",
+                            "module_name": "great_expectations.datasource.data_connector.asset",
+                        }
+                    },
                     "class_name": "RuntimeDataConnector",
+                    "module_name": "great_expectations.datasource.data_connector",
                 },
             },
+            "execution_engine": {
+                "class_name": "PandasExecutionEngine",
+                "module_name": "great_expectations.execution_engine",
+            },
+            "module_name": "great_expectations.datasource",
             "name": "my_datasource",
         }
     ]
