@@ -1115,7 +1115,7 @@ def test_suite_edit_multiple_datasources_with_generator_with_batch_kwargs_arg(
 
 @mock.patch("subprocess.call", return_value=True, side_effect=None)
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
-def test_suite_edit_on_exsiting_suite_one_datasources_with_batch_kwargs_without_datasource_raises_helpful_error(
+def test_suite_edit_on_existing_suite_one_datasources_with_batch_kwargs_without_datasource_raises_helpful_error(
     mock_webbrowser,
     mock_subprocess,
     caplog,
@@ -1156,7 +1156,7 @@ def test_suite_edit_on_exsiting_suite_one_datasources_with_batch_kwargs_without_
     stdout = result.output
     assert result.exit_code == 1
     assert "Please check that your batch_kwargs are able to load a batch." in stdout
-    assert "Unable to load datasource `None`" in stdout
+    assert "Must provide a datasource_name to retrieve an existing Datasource" in stdout
 
     assert mock_webbrowser.call_count == 0
     assert mock_subprocess.call_count == 0
