@@ -255,16 +255,13 @@ def test_test_column_map_expectation_function():
         is_odd, column="y", result_format="BOOLEAN_ONLY", include_config=False
     ) == ExpectationValidationResult(success=False)
 
-    assert (
-        asset.test_column_map_expectation_function(
-            is_odd,
-            column="y",
-            result_format="BOOLEAN_ONLY",
-            mostly=0.7,
-            include_config=False,
-        )
-        == ExpectationValidationResult(success=True)
-    )
+    assert asset.test_column_map_expectation_function(
+        is_odd,
+        column="y",
+        result_format="BOOLEAN_ONLY",
+        mostly=0.7,
+        include_config=False,
+    ) == ExpectationValidationResult(success=True)
 
 
 def test_test_column_aggregate_expectation_function():
@@ -322,27 +319,21 @@ def test_test_column_aggregate_expectation_function():
         success=True,
     )
 
-    assert (
-        asset.test_column_aggregate_expectation_function(
-            expect_second_value_to_be,
-            "y",
-            value=3,
-            result_format="BOOLEAN_ONLY",
-            include_config=False,
-        )
-        == ExpectationValidationResult(success=False)
-    )
+    assert asset.test_column_aggregate_expectation_function(
+        expect_second_value_to_be,
+        "y",
+        value=3,
+        result_format="BOOLEAN_ONLY",
+        include_config=False,
+    ) == ExpectationValidationResult(success=False)
 
-    assert (
-        asset.test_column_aggregate_expectation_function(
-            expect_second_value_to_be,
-            "y",
-            2,
-            result_format="BOOLEAN_ONLY",
-            include_config=False,
-        )
-        == ExpectationValidationResult(success=True)
-    )
+    assert asset.test_column_aggregate_expectation_function(
+        expect_second_value_to_be,
+        "y",
+        2,
+        result_format="BOOLEAN_ONLY",
+        include_config=False,
+    ) == ExpectationValidationResult(success=True)
 
 
 def test_format_map_output():
@@ -363,18 +354,15 @@ def test_format_map_output():
     unexpected_list = []
     unexpected_index_list = []
 
-    assert (
-        df._format_map_output(
-            "BOOLEAN_ONLY",
-            success,
-            element_count,
-            nonnull_count,
-            len(unexpected_list),
-            unexpected_list,
-            unexpected_index_list,
-        )
-        == {"success": True}
-    )
+    assert df._format_map_output(
+        "BOOLEAN_ONLY",
+        success,
+        element_count,
+        nonnull_count,
+        len(unexpected_list),
+        unexpected_list,
+        unexpected_index_list,
+    ) == {"success": True}
 
     assert df._format_map_output(
         "BASIC",
@@ -452,25 +440,22 @@ def test_format_map_output():
 
     success = True
     element_count = 20
-    nonnull_values = pd.Series([])
+    nonnull_values = pd.Series([], dtype=np.float64)
     nonnull_count = 0
-    boolean_mapped_success_values = pd.Series([])
+    boolean_mapped_success_values = pd.Series([], dtype=np.float64)
     success_count = 0
     unexpected_list = []
     unexpected_index_list = []
 
-    assert (
-        df._format_map_output(
-            "BOOLEAN_ONLY",
-            success,
-            element_count,
-            nonnull_count,
-            len(unexpected_list),
-            unexpected_list,
-            unexpected_index_list,
-        )
-        == {"success": True}
-    )
+    assert df._format_map_output(
+        "BOOLEAN_ONLY",
+        success,
+        element_count,
+        nonnull_count,
+        len(unexpected_list),
+        unexpected_list,
+        unexpected_index_list,
+    ) == {"success": True}
 
     assert df._format_map_output(
         "BASIC",
@@ -548,25 +533,22 @@ def test_format_map_output():
 
     success = False
     element_count = 0
-    nonnull_values = pd.Series([])
+    nonnull_values = pd.Series([], dtype=np.float64)
     nonnull_count = 0
-    boolean_mapped_success_values = pd.Series([])
+    boolean_mapped_success_values = pd.Series([], dtype=np.float64)
     success_count = 0
     unexpected_list = []
     unexpected_index_list = []
 
-    assert (
-        df._format_map_output(
-            "BOOLEAN_ONLY",
-            success,
-            element_count,
-            nonnull_count,
-            len(unexpected_list),
-            unexpected_list,
-            unexpected_index_list,
-        )
-        == {"success": False}
-    )
+    assert df._format_map_output(
+        "BOOLEAN_ONLY",
+        success,
+        element_count,
+        nonnull_count,
+        len(unexpected_list),
+        unexpected_list,
+        unexpected_index_list,
+    ) == {"success": False}
 
     assert df._format_map_output(
         "BASIC",
