@@ -4,6 +4,10 @@ from great_expectations.data_context.store import DatasourceStore
 from great_expectations.data_context.store.ge_cloud_store_backend import (
     GeCloudRESTResource,
 )
+from great_expectations.data_context.types.base import datasourceConfigSchema
+from great_expectations.datasource.datasource_serializer import (
+    JsonDatasourceConfigSerializer,
+)
 
 
 @pytest.fixture
@@ -27,5 +31,6 @@ def datasource_store_ge_cloud_backend(
     store = DatasourceStore(
         store_name=datasource_store_name,
         store_backend=ge_cloud_store_backend_config,
+        serializer=JsonDatasourceConfigSerializer(schema=datasourceConfigSchema),
     )
     return store
