@@ -1,11 +1,13 @@
 import json
 import os
 import shutil
-from typing import List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
 import pytest
 
+from great_expectations.util import is_candidate_subset_of_target
+
 try:
     pyspark = pytest.importorskip("pyspark")
     from pyspark.sql.types import Row
@@ -235,13 +237,32 @@ def test_basic_pandas_datasource_v013_self_check(basic_pandas_datasource_v013):
 
 
 def test_basic_spark_datasource_self_check(basic_spark_datasource):
-    report = basic_spark_datasource.self_check()
-    report["execution_engine"]["spark_config"].pop("spark.app.id", None)
-    report["execution_engine"]["spark_config"].pop("spark.driver.host", None)
-    report["execution_engine"]["spark_config"].pop("spark.driver.port", None)
-    report["execution_engine"]["spark_config"].pop("spark.submit.pyFiles", None)
-    report["execution_engine"]["spark_config"].pop("spark.app.startTime", None)
-    report["execution_engine"]["spark_config"].pop("spark.sql.warehouse.dir", None)
+    report: dict = basic_spark_datasource.self_check()
+
+    # The structure of this config is dynamic based on PySpark version;
+    # we deem asserting certain key-value pairs sufficient for purposes of this test
+    expected_spark_config: Dict[str, str] = {
+        "spark.app.name": "default_great_expectations_spark_application",
+        "spark.default.parallelism": "4",
+        "spark.driver.memory": "6g",
+        "spark.executor.id": "driver",
+        "spark.executor.memory": "6g",
+        "spark.master": "local[*]",
+        "spark.rdd.compress": "True",
+        "spark.serializer.objectStreamReset": "100",
+        "spark.sql.catalogImplementation": "hive",
+        "spark.sql.shuffle.partitions": "2",
+        "spark.submit.deployMode": "client",
+        "spark.ui.showConsoleProgress": "False",
+    }
+    actual_spark_config: Dict[str, Any] = report["execution_engine"]["spark_config"]
+
+    assert is_candidate_subset_of_target(
+        candidate=expected_spark_config, target=actual_spark_config
+    )
+
+    # Remove Spark-specific information so we can assert against the rest of the payload
+    report["execution_engine"].pop("spark_config")
 
     assert report == {
         "data_connectors": {
@@ -270,20 +291,6 @@ def test_basic_spark_datasource_self_check(basic_spark_datasource):
             "class_name": "SparkDFExecutionEngine",
             "module_name": "great_expectations.execution_engine.sparkdf_execution_engine",
             "persist": True,
-            "spark_config": {
-                "spark.app.name": "default_great_expectations_spark_application",
-                "spark.default.parallelism": "4",
-                "spark.driver.memory": "6g",
-                "spark.executor.id": "driver",
-                "spark.executor.memory": "6g",
-                "spark.master": "local[*]",
-                "spark.rdd.compress": "True",
-                "spark.serializer.objectStreamReset": "100",
-                "spark.sql.catalogImplementation": "hive",
-                "spark.sql.shuffle.partitions": "2",
-                "spark.submit.deployMode": "client",
-                "spark.ui.showConsoleProgress": "False",
-            },
         },
     }
 
