@@ -1,6 +1,6 @@
 import datetime
 import os
-from typing import List
+from typing import List, Optional
 from unittest import mock
 
 import pandas as pd
@@ -28,9 +28,19 @@ from tests.execution_engine.split_and_sample.split_and_sample_test_cases import
 
 # Here we add SqlAlchemyDataSplitter specific test cases to the generic test cases:
 from tests.integration.fixtures.split_and_sample_data.splitter_test_cases_and_fixtures import (
-    TaxiSplittingTestCases,
+    TaxiSplittingTestCase,
+    TaxiSplittingTestCasesBase,
+    TaxiSplittingTestCasesColumnValue,
+    TaxiSplittingTestCasesConvertedDateTime,
+    TaxiSplittingTestCasesDateTime,
+    TaxiSplittingTestCasesDividedInteger,
+    TaxiSplittingTestCasesHashedColumn,
+    TaxiSplittingTestCasesModInteger,
+    TaxiSplittingTestCasesMultiColumnValues,
+    TaxiSplittingTestCasesWholeTable,
     TaxiTestData,
 )
+from tests.test_utils import convert_string_columns_to_datetime
 
 SINGLE_DATE_PART_DATE_PARTS += [
     pytest.param(
@@ -68,7 +78,7 @@ def test_named_date_part_methods(
     """Test that a partially pre-filled version of split_on_date_parts() was called with the appropriate params.
     For example, split_on_year.
     """
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     column_name: str = "column_name"
     batch_identifiers: dict = {column_name: {"year": 2018, "month": 10, "day": 31}}
 
@@ -103,7 +113,7 @@ def test_split_on_date_parts_single_date_parts(
      or a datetime and also fail when parameters are invalid.
     """
 
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     column_name: str = "column_name"
 
     result: sa.sql.elements.BooleanClauseList = data_splitter.split_on_date_parts(
@@ -148,7 +158,7 @@ def test_split_on_date_parts_multiple_date_parts(
      or a datetime and also fail when parameters are invalid.
     """
 
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     column_name: str = "column_name"
 
     result: sa.sql.elements.BooleanClauseList = data_splitter.split_on_date_parts(
@@ -190,7 +200,7 @@ def test_get_data_for_batch_identifiers_year(
     mock_get_data_for_batch_identifiers_for_split_on_date_parts: mock.MagicMock,
 ):
     """test that get_data_for_batch_identifiers_for_split_on_date_parts() was called with the appropriate params."""
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     table_name: str = "table_name"
     column_name: str = "column_name"
 
@@ -217,7 +227,7 @@ def test_get_data_for_batch_identifiers_year_and_month(
     mock_get_data_for_batch_identifiers_for_split_on_date_parts: mock.MagicMock,
 ):
     """test that get_data_for_batch_identifiers_for_split_on_date_parts() was called with the appropriate params."""
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     table_name: str = "table_name"
     column_name: str = "column_name"
 
@@ -244,7 +254,7 @@ def test_get_data_for_batch_identifiers_year_and_month_and_day(
     mock_get_data_for_batch_identifiers_for_split_on_date_parts: mock.MagicMock,
 ):
     """test that get_data_for_batch_identifiers_for_split_on_date_parts() was called with the appropriate params."""
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     table_name: str = "table_name"
     column_name: str = "column_name"
 
@@ -275,7 +285,7 @@ def test_get_split_query_for_data_for_batch_identifiers_for_split_on_date_parts_
     query when passed a single element list of date_parts that is a string, DatePart enum object, or mixed case string.
     """
 
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     table_name: str = "table_name"
     column_name: str = "column_name"
 
@@ -316,7 +326,7 @@ def test_get_split_query_for_data_for_batch_identifiers_for_split_on_date_parts_
     get_split_query_for_data_for_batch_identifiers_for_split_on_date_parts should
     return the correct query when passed any valid set of parameters including multiple date parts.
     """
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
     table_name: str = "table_name"
     column_name: str = "column_name"
 
@@ -328,25 +338,16 @@ def test_get_split_query_for_data_for_batch_identifiers_for_split_on_date_parts_
 
     assert isinstance(result, sa.sql.Select)
 
-    query_str: str = (
+    expected_query_str: str = "SELECT distinct(concat(concat('', CAST(EXTRACT(year FROM column_name) AS VARCHAR)), CAST(EXTRACT(month FROM column_name) AS VARCHAR))) AS concat_distinct_values, CAST(EXTRACT(year FROM column_name) AS INTEGER) AS year, CAST(EXTRACT(month FROM column_name) AS INTEGER) AS month FROM table_name"
+    actual_query_str: str = (
         str(result.compile(compile_kwargs={"literal_binds": True}))
         .replace("\n", "")
         .replace(" ", "")
         .lower()
     )
     assert (
-        query_str
-        == (
-            "SELECT distinct(concat("
-            "CAST(EXTRACT(year FROM column_name) AS VARCHAR), CAST(EXTRACT(month FROM column_name) AS VARCHAR)"
-            ")) AS concat_distinct_values,"
-            "CAST(EXTRACT(year FROM column_name) AS INTEGER) AS year,"
-            "CAST(EXTRACT(month FROM column_name) AS INTEGER) AS month"
-            "FROM table_name"
-        )
-        .replace("\n", "")
-        .replace(" ", "")
-        .lower()
+        actual_query_str
+        == expected_query_str.replace("\n", "").replace(" ", "").lower()
     )
 
 
@@ -377,7 +378,7 @@ def test_get_split_query_for_data_for_batch_identifiers_for_split_on_date_parts_
     ],
 )
 def test_get_splitter_method(underscore_prefix: str, splitter_method_name: str):
-    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter()
+    data_splitter: SqlAlchemyDataSplitter = SqlAlchemyDataSplitter(dialect="sqlite")
 
     splitter_method_name_with_prefix = f"{underscore_prefix}{splitter_method_name}"
 
@@ -396,60 +397,152 @@ def ten_trips_per_month_df() -> pd.DataFrame:
             "yellow_tripdata_sample_10_trips_from_each_month.csv",
         ),
     )
-    # Convert pickup_datetime to a datetime type column
     df: pd.DataFrame = pd.read_csv(csv_path)
-    column_names_to_convert: List[str] = ["pickup_datetime", "dropoff_datetime"]
-    for column_name_to_convert in column_names_to_convert:
-        df[column_name_to_convert] = pd.to_datetime(df[column_name_to_convert])
     return df
 
 
 @pytest.fixture
 def in_memory_sqlite_taxi_ten_trips_per_month_execution_engine(sa):
-    engine: SqlAlchemyExecutionEngine = build_sa_engine(ten_trips_per_month_df(), sa)
-    return engine
-
-
-TAXI_SPLITTING_TEST_CASES: TaxiSplittingTestCases = TaxiSplittingTestCases(
-    taxi_test_data=TaxiTestData(
-        test_df=ten_trips_per_month_df(), test_column_name="pickup_datetime"
+    df: pd.DataFrame = ten_trips_per_month_df()
+    convert_string_columns_to_datetime(
+        df=df, column_names_to_convert=["pickup_datetime", "dropoff_datetime"]
     )
-)
+    engine: SqlAlchemyExecutionEngine = build_sa_engine(df, sa)
+    return engine
 
 
 @pytest.mark.integration
 @pytest.mark.parametrize(
-    "test_case",
+    "taxi_test_cases",
     [
-        pytest.param(test_case, id=test_case.splitter_method_name)
-        for test_case in TAXI_SPLITTING_TEST_CASES.test_cases()
+        TaxiSplittingTestCasesWholeTable(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name=None,
+                test_column_names=None,
+                column_names_to_convert=["pickup_datetime", "dropoff_datetime"],
+            )
+        ),
+        TaxiSplittingTestCasesColumnValue(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name="passenger_count",
+                test_column_names=None,
+                column_names_to_convert=["pickup_datetime", "dropoff_datetime"],
+            )
+        ),
+        TaxiSplittingTestCasesDividedInteger(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name="pickup_location_id",
+                test_column_names=None,
+                column_names_to_convert=["pickup_datetime", "dropoff_datetime"],
+            )
+        ),
+        TaxiSplittingTestCasesModInteger(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name="pickup_location_id",
+                test_column_names=None,
+                column_names_to_convert=["pickup_datetime", "dropoff_datetime"],
+            )
+        ),
+        TaxiSplittingTestCasesHashedColumn(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name="pickup_location_id",
+                test_column_names=None,
+                column_names_to_convert=["pickup_datetime", "dropoff_datetime"],
+            )
+        ),
+        TaxiSplittingTestCasesMultiColumnValues(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name=None,
+                test_column_names=[
+                    "rate_code_id",
+                    "payment_type",
+                ],
+                column_names_to_convert=["pickup_datetime", "dropoff_datetime"],
+            )
+        ),
+        TaxiSplittingTestCasesDateTime(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name="pickup_datetime",
+                test_column_names=None,
+                column_names_to_convert=["pickup_datetime", "dropoff_datetime"],
+            )
+        ),
+        TaxiSplittingTestCasesConvertedDateTime(
+            taxi_test_data=TaxiTestData(
+                test_df=ten_trips_per_month_df(),
+                test_column_name="pickup_datetime",
+                test_column_names=None,
+                column_names_to_convert=None,
+            )
+        ),
     ],
 )
 def test_sqlite_split(
-    test_case, sa, in_memory_sqlite_taxi_ten_trips_per_month_execution_engine
+    taxi_test_cases: TaxiSplittingTestCasesBase,
+    sa,
 ):
     """What does this test and why?
     splitters should work with sqlite.
     """
+    engine: SqlAlchemyExecutionEngine = build_sa_engine(taxi_test_cases.test_df, sa)
 
-    engine: SqlAlchemyExecutionEngine = (
-        in_memory_sqlite_taxi_ten_trips_per_month_execution_engine
-    )
+    test_cases: List[TaxiSplittingTestCase] = taxi_test_cases.test_cases()
+    test_case: TaxiSplittingTestCase
+    batch_spec: SqlAlchemyDatasourceBatchSpec
+    for test_case in test_cases:
+        if test_case.table_domain_test_case:
+            batch_spec = SqlAlchemyDatasourceBatchSpec(
+                table_name="test",
+                schema_name="main",
+                splitter_method=test_case.splitter_method_name,
+                splitter_kwargs=test_case.splitter_kwargs,
+                batch_identifiers={},
+            )
+        else:
+            if taxi_test_cases.test_column_name:
+                batch_spec = SqlAlchemyDatasourceBatchSpec(
+                    table_name="test",
+                    schema_name="main",
+                    splitter_method=test_case.splitter_method_name,
+                    splitter_kwargs=test_case.splitter_kwargs,
+                    batch_identifiers={
+                        taxi_test_cases.test_column_name: test_case.expected_column_values[
+                            0
+                        ]
+                    },
+                )
+            elif taxi_test_cases.test_column_names:
+                column_name: str
+                batch_spec = SqlAlchemyDatasourceBatchSpec(
+                    table_name="test",
+                    schema_name="main",
+                    splitter_method=test_case.splitter_method_name,
+                    splitter_kwargs=test_case.splitter_kwargs,
+                    batch_identifiers={
+                        column_name: test_case.expected_column_values[0][column_name]
+                        for column_name in taxi_test_cases.test_column_names
+                    },
+                )
+            else:
+                raise ValueError(
+                    "Missing test_column_names or test_column_names attribute."
+                )
 
-    batch_spec: SqlAlchemyDatasourceBatchSpec = SqlAlchemyDatasourceBatchSpec(
-        table_name="test",
-        schema_name="main",
-        splitter_method=test_case.splitter_method_name,
-        splitter_kwargs=test_case.splitter_kwargs,
-        batch_identifiers={"pickup_datetime": test_case.expected_pickup_datetimes[0]},
-    )
-    batch_data: SqlAlchemyBatchData = engine.get_batch_data(batch_spec=batch_spec)
+        batch_data: SqlAlchemyBatchData = engine.get_batch_data(batch_spec=batch_spec)
 
-    # Right number of rows?
-    num_rows: int = batch_data.execution_engine.engine.execute(
-        sa.select([sa.func.count()]).select_from(batch_data.selectable)
-    ).scalar()
-    assert num_rows == test_case.num_expected_rows_in_first_batch_definition
+        # Right number of rows?
+        num_rows: int = batch_data.execution_engine.engine.execute(
+            sa.select([sa.func.count()]).select_from(batch_data.selectable)
+        ).scalar()
+        # noinspection PyUnresolvedReferences
+        assert num_rows == test_case.num_expected_rows_in_first_batch_definition
 
 
 @pytest.mark.integration
