@@ -204,7 +204,7 @@ def test_pandas_unexpected_rows_basic_result_format(dataframe_for_unexpected_row
     )
 
     expectation = ExpectColumnValuesToBeInSet(expectationConfiguration)
-    batch: Batch = Batch(data=dataframe_for_unexpected_rows)
+    batch = Batch(data=dataframe_for_unexpected_rows)
     engine = PandasExecutionEngine()
     validator = Validator(
         execution_engine=engine,
@@ -241,7 +241,7 @@ def test_pandas_unexpected_rows_complete_result_format(dataframe_for_unexpected_
     )
 
     expectation = ExpectColumnValuesToBeInSet(expectationConfiguration)
-    batch: Batch = Batch(data=dataframe_for_unexpected_rows)
+    batch = Batch(data=dataframe_for_unexpected_rows)
     engine = PandasExecutionEngine()
     validator = Validator(
         execution_engine=engine,
@@ -285,7 +285,7 @@ def test_pandas_default_to_not_include_unexpected_rows(
     )
 
     expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
-    batch: Batch = Batch(data=dataframe_for_unexpected_rows)
+    batch = Batch(data=dataframe_for_unexpected_rows)
     engine = PandasExecutionEngine()
     validator = Validator(
         execution_engine=engine,
@@ -313,7 +313,7 @@ def test_pandas_specify_not_include_unexpected_rows(
     )
 
     expectation = ExpectColumnValuesToBeInSet(expectationConfiguration)
-    batch: Batch = Batch(data=dataframe_for_unexpected_rows)
+    batch = Batch(data=dataframe_for_unexpected_rows)
     engine = PandasExecutionEngine()
     validator = Validator(
         execution_engine=engine,
@@ -340,7 +340,7 @@ def test_include_unexpected_rows_without_explicit_result_format_raises_error(
     )
 
     expectation = ExpectColumnValuesToBeInSet(expectationConfiguration)
-    batch: Batch = Batch(data=dataframe_for_unexpected_rows)
+    batch = Batch(data=dataframe_for_unexpected_rows)
     engine = PandasExecutionEngine()
     validator = Validator(
         execution_engine=engine,
