@@ -15,10 +15,7 @@ from great_expectations.core.metric_domain_types import MetricDomainTypes
 from great_expectations.core.usage_statistics.events import UsageStatsEvents
 from great_expectations.rule_based_profiler.altair import AltairDataTypes
 from great_expectations.rule_based_profiler.config import RuleBasedProfilerConfig
-from great_expectations.rule_based_profiler.data_assistant import (
-    DataAssistant,
-    VolumeDataAssistant,
-)
+from great_expectations.rule_based_profiler.data_assistant import VolumeDataAssistant
 from great_expectations.rule_based_profiler.data_assistant.data_assistant_runner import (
     NumericRangeEstimatorType,
 )
@@ -977,6 +974,7 @@ def quentin_expected_rule_based_profiler_configuration() -> Callable:
                             "replace_nan_with_zero": True,
                             "name": "table_row_count",
                             "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
+                            "single_batch_mode": False,
                             "enforce_numeric_metric": True,
                             "class_name": "MetricMultiBatchParameterBuilder",
                             "reduce_scalar_metric": True,
@@ -1017,6 +1015,7 @@ def quentin_expected_rule_based_profiler_configuration() -> Callable:
                                             "metric_value_kwargs": None,
                                             "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                                             "metric_domain_kwargs": None,
+                                            "single_batch_mode": False,
                                             "reduce_scalar_metric": True,
                                             "metric_name": "table.row_count",
                                         }
@@ -1073,6 +1072,7 @@ def quentin_expected_rule_based_profiler_configuration() -> Callable:
                             "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                             "enforce_numeric_metric": True,
                             "class_name": "MetricMultiBatchParameterBuilder",
+                            "single_batch_mode": False,
                             "reduce_scalar_metric": True,
                             "metric_name": "column.distinct_values.count",
                         },
@@ -1120,6 +1120,7 @@ def quentin_expected_rule_based_profiler_configuration() -> Callable:
                                             "metric_value_kwargs": None,
                                             "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                                             "metric_domain_kwargs": "$domain.domain_kwargs",
+                                            "single_batch_mode": False,
                                             "reduce_scalar_metric": True,
                                             "metric_name": "column.distinct_values.count",
                                         }
@@ -2064,8 +2065,8 @@ def test_volume_data_assistant_execution_time_within_proper_bounds_using_explici
     data_assistant_result: DataAssistantResult
     validator, data_assistant_result = quentin_explicit_instantiation_result_actual_time
 
-    # Execution time (in seconds) must have non-trivial value.
-    assert data_assistant_result.execution_time > 0.0
+    # Rule-Based Profiler execution time (in seconds) must have non-trivial value.
+    assert data_assistant_result.profiler_execution_time > 0.0
 
 
 @pytest.mark.unit
@@ -2076,8 +2077,8 @@ def test_volume_data_assistant_execution_time_within_proper_bounds_using_implici
         quentin_implicit_invocation_result_actual_time
     )
 
-    # Execution time (in seconds) must have non-trivial value.
-    assert data_assistant_result.execution_time > 0.0
+    # Rule-Based Profiler execution time (in seconds) must have non-trivial value.
+    assert data_assistant_result.profiler_execution_time > 0.0
 
 
 @pytest.mark.unit
