@@ -1,8 +1,8 @@
 from typing import Dict, List
 
-from great_expectations.execution_engine.execution_engine import MetricDomainTypes
-from great_expectations.rule_based_profiler.types import (
-    Domain,
+from great_expectations.core.metric_domain_types import MetricDomainTypes
+from great_expectations.rule_based_profiler.domain import Domain
+from great_expectations.rule_based_profiler.parameter_container import (
     ParameterContainer,
     ParameterNode,
     build_parameter_container,
@@ -16,7 +16,7 @@ def test_build_parameter_container(
     parameters_with_different_depth_level_values,
     multi_part_name_parameter_container,
 ):
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameter_container = ParameterContainer(parameter_nodes=None)
     build_parameter_container(
         parameter_container=parameter_container,
         parameter_values=parameters_with_different_depth_level_values,
@@ -27,13 +27,13 @@ def test_build_parameter_container(
 def test_get_fully_qualified_parameter_names(
     parameters_with_different_depth_level_values,
 ):
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameter_container = ParameterContainer(parameter_nodes=None)
     build_parameter_container(
         parameter_container=parameter_container,
         parameter_values=parameters_with_different_depth_level_values,
     )
 
-    domain: Domain = Domain(
+    domain = Domain(
         domain_type=MetricDomainTypes.COLUMN,
         domain_kwargs=None,
         details=None,
@@ -83,13 +83,13 @@ def test_get_fully_qualified_parameter_names(
 def test_get_parameter_values_for_fully_qualified_parameter_names(
     parameters_with_different_depth_level_values,
 ):
-    parameter_container: ParameterContainer = ParameterContainer(parameter_nodes=None)
+    parameter_container = ParameterContainer(parameter_nodes=None)
     build_parameter_container(
         parameter_container=parameter_container,
         parameter_values=parameters_with_different_depth_level_values,
     )
 
-    domain: Domain = Domain(
+    domain = Domain(
         domain_type=MetricDomainTypes.COLUMN,
         domain_kwargs=None,
         details=None,
