@@ -177,6 +177,7 @@ def test_reconcile_profiler_rules_new_rule_override(
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": False,
                     "replace_nan_with_zero": False,
                     "reduce_scalar_metric": True,
@@ -239,6 +240,7 @@ def test_reconcile_profiler_rules_new_rule_override(
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": False,
                     "replace_nan_with_zero": False,
                     "reduce_scalar_metric": True,
@@ -309,6 +311,7 @@ def test_reconcile_profiler_rules_existing_rule_domain_builder_override(
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": False,
                     "replace_nan_with_zero": False,
                     "reduce_scalar_metric": True,
@@ -358,6 +361,7 @@ def test_reconcile_profiler_rules_existing_rule_parameter_builder_overrides(
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_special_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": True,
                     "replace_nan_with_zero": True,
                     "reduce_scalar_metric": True,
@@ -391,6 +395,7 @@ def test_reconcile_profiler_rules_existing_rule_parameter_builder_overrides(
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_special_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": True,
                     "replace_nan_with_zero": True,
                     "reduce_scalar_metric": True,
@@ -494,6 +499,7 @@ def test_reconcile_profiler_rules_existing_rule_expectation_configuration_builde
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": False,
                     "replace_nan_with_zero": False,
                     "reduce_scalar_metric": True,
@@ -615,6 +621,7 @@ def test_reconcile_profiler_rules_existing_rule_full_rule_override_nested_update
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": False,
                     "replace_nan_with_zero": False,
                     "reduce_scalar_metric": True,
@@ -860,6 +867,7 @@ def test_reconcile_profiler_rules_existing_rule_full_rule_override_update(
                     "module_name": "great_expectations.rule_based_profiler.parameter_builder.metric_multi_batch_parameter_builder",
                     "name": "my_parameter",
                     "metric_name": "my_metric",
+                    "single_batch_mode": False,
                     "enforce_numeric_metric": False,
                     "replace_nan_with_zero": False,
                     "reduce_scalar_metric": True,
@@ -1105,6 +1113,7 @@ def test_serialize_profiler_config(
         "metric_name": "my_metric",
         "metric_domain_kwargs": None,
         "metric_value_kwargs": None,
+        "single_batch_mode": False,
         "enforce_numeric_metric": False,
         "replace_nan_with_zero": False,
         "reduce_scalar_metric": True,
@@ -1168,7 +1177,6 @@ def test_add_profiler_ge_cloud_mode(
         profiler_config_with_placeholder_args,
         data_context=mock_data_context,
         profiler_store=mock_data_context.profiler_store,
-        ge_cloud_id=ge_cloud_profiler_id,
     )
 
     assert isinstance(profiler, RuleBasedProfiler)
